==> haskell-quickcheck-unicode-1.0.1.0-297-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-unicode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quickcheck-unicode
version:              1.0.1.0
visibility:           public
id:                   quickcheck-unicode-1.0.1.0-LuE1MOGgZKQ3z4waWRu5Vt
key:                  quickcheck-unicode-1.0.1.0-LuE1MOGgZKQ3z4waWRu5Vt
license:              BSD-2-Clause
copyright:            2014-2017 Bryan O'\''Sullivan
maintainer:           Bryan O'\''Sullivan <bos@serpentine.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/bos/quickcheck-unicode
synopsis:
    Generator and shrink functions for testing
    Unicode-related software.

description:
    Generator and shrink functions for testing
    Unicode-related software.

category:             Testing, Text
abi:                  d88431435b93d0023f18894ae58587bd
exposed:              True
exposed-modules:      Test.QuickCheck.Unicode
import-dirs:          /usr/lib/ghc-9.4.8/site-local/quickcheck-unicode-1.0.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/quickcheck-unicode-1.0.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/quickcheck-unicode-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-unicode
hs-libraries:         HSquickcheck-unicode-1.0.1.0-LuE1MOGgZKQ3z4waWRu5Vt
depends:
    QuickCheck-2.14.3-4HbOe3sBZbX6PbIkQ49pGG base-4.17.2.1

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-unicode/html/quickcheck-unicode.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-unicode/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-unicode-1.0.1.0-298-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-unicode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quickcheck-unicode
version:              1.0.1.0
visibility:           public
id:                   quickcheck-unicode-1.0.1.0-CmuBDhJulju8NZ17hu44ge
key:                  quickcheck-unicode-1.0.1.0-CmuBDhJulju8NZ17hu44ge
license:              BSD-2-Clause
copyright:            2014-2017 Bryan O'\''Sullivan
maintainer:           Bryan O'\''Sullivan <bos@serpentine.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/bos/quickcheck-unicode
synopsis:
    Generator and shrink functions for testing
    Unicode-related software.

description:
    Generator and shrink functions for testing
    Unicode-related software.

category:             Testing, Text
abi:                  cf04edc759207177519e1704adb40a49
exposed:              True
exposed-modules:      Test.QuickCheck.Unicode
import-dirs:          /usr/lib/ghc-9.4.8/site-local/quickcheck-unicode-1.0.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/quickcheck-unicode-1.0.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/quickcheck-unicode-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-unicode
hs-libraries:         HSquickcheck-unicode-1.0.1.0-CmuBDhJulju8NZ17hu44ge
depends:
    QuickCheck-2.14.3-CpTyyGCQ8vELJYAkeHIgu4 base-4.17.2.1

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-unicode/html/quickcheck-unicode.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-unicode/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
